Stan Math Library: stan/math/prim/scal/prob/normal_rng.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

normal_rng.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_PROB_NORMAL_RNG_HPP
2 #define STAN_MATH_PRIM_SCAL_PROB_NORMAL_RNG_HPP
3
4 #include <boost/random/normal_distribution.hpp>
5 #include <boost/random/variate_generator.hpp>
6 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
7 #include <stan/math/prim/scal/err/check_finite.hpp>
8 #include <stan/math/prim/scal/err/check_not_nan.hpp>
9 #include <stan/math/prim/scal/err/check_positive.hpp>
10 #include <stan/math/prim/scal/fun/constants.hpp>
11 #include <stan/math/prim/scal/fun/value_of.hpp>
12
13 namespace stan {
14
15 namespace math {
16
17 template <class RNG>
18 inline double
19 normal_rng(const double mu,
20 const double sigma,
21 RNG& rng) {
22 using boost::variate_generator;
23 using boost::normal_distribution;
24 using stan::math::check_positive;
25 using stan::math::check_finite;
26 using stan::math::check_not_nan;
27
28 static const char* function("stan::math::normal_rng");
29
30 check_finite(function, "Location parameter", mu);
31 check_not_nan(function, "Location parameter", mu);
32 check_positive(function, "Scale parameter", sigma);
33 check_not_nan(function, "Scale parameter", sigma);
34
35 variate_generator<RNG&, normal_distribution<> >
36 norm_rng(rng, normal_distribution<>(mu, sigma));
37 return norm_rng();
38 }
39 }
40 }
41 #endif
check_not_nan.hpp
stan::math::check_not_nan
bool check_not_nan(const char *function, const char *name, const T_y &y)
Return true if y is not NaN.
Definition: check_not_nan.hpp:63
check_positive.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::check_positive
bool check_positive(const char *function, const char *name, const T_y &y)
Return true if y is positive.
Definition: check_positive.hpp:68
stan::math::check_finite
bool check_finite(const char *function, const char *name, const T_y &y)
Return true if y is finite.
Definition: check_finite.hpp:62
constants.hpp
check_finite.hpp
value_of.hpp
stan::math::normal_rng
double normal_rng(const double mu, const double sigma, RNG &rng)
Definition: normal_rng.hpp:19
check_consistent_sizes.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.